@@ -1365,8 +1365,8 @@ class Database:
                     df = df.rename(columns={'change_in_settlement': 'close_change'})
                 if 'year_month' in df.columns:
                     df = df.rename(columns={'year_month': 'contract_month'})
-
-
+                if 'volumne' in df.columns:
+                    df = df.rename(columns={'volumne': 'volume'})
                 return df
 
         else:
